package main

import (
	"bufio"
	"context"
	"errors"
	"fmt"
	"io"
	"os"
	"strings"

	"dehub.dev/src/dehub.git/cmd/dehub/dcmd"

	"gopkg.in/src-d/go-git.v4/plumbing"
)

func cmdHook(ctx context.Context, cmd *dcmd.Cmd) {
	flag := cmd.FlagSet()
	var proj proj
	proj.initFlags(flag)

	body := func() (context.Context, error) {
		if err := proj.openProj(); err != nil {
			return nil, err
		}
		return ctx, nil
	}

	cmd.SubCmd("pre-receive", "Use dehub as a server-side pre-receive hook",
		func(ctx context.Context, cmd *dcmd.Cmd) {
			cmd.Run(func() (context.Context, error) {
				br := bufio.NewReader(os.Stdin)
				for {
					line, err := br.ReadString('\n')
					if errors.Is(err, io.EOF) {
						break
					} else if err != nil {
						return nil, fmt.Errorf("error reading next line from stdin: %w", err)
					}
					fmt.Printf("Processing line %q\n", strings.TrimSpace(line))

					lineParts := strings.Fields(line)
					if len(lineParts) < 3 {
						return nil, fmt.Errorf("malformed pre-receive hook stdin line %q", line)
					}

					endHash := plumbing.NewHash(lineParts[1])
					branchName := plumbing.ReferenceName(lineParts[2])

					if !branchName.IsBranch() {
						return nil, fmt.Errorf("reference %q is not a branch, can't push to it", branchName)
					} else if endHash == plumbing.ZeroHash {
						return nil, errors.New("deleting remote branches is not currently supported")
					}

					return nil, proj.VerifyCanSetBranchHEADTo(branchName, endHash)
				}

				fmt.Println("All pushed commits have been verified, well done.")
				return nil, nil
			})
		},
	)

	cmd.Run(body)
}
